Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( BuildInfo = prometheus.NewGaugeVec( prometheus.GaugeOpts{ Namespace: namespace, Name: "build_info", Help: "Build Information", }, []string{ "build_time", "version", "git_ref_name", "git_ref_sha", }, ) )
Metrics used throughout the application for troubleshooting and health indicators.
Functions ¶
func Heartbeat ¶
Heartbeat is application heartbeat that continuously beats at configurable fixed interval. It emits few metrics every configured intervals to say that the app is alive and provide the stats
func RegisterTo ¶
func RegisterTo(target prometheus.Registerer) error
RegisterTo registers metrics to a desired target Registerer.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.